@@ -1,12 +1,13 @@
 package Dist::Zilla::Plugin::DROLSKY::Contributors;
-$Dist::Zilla::Plugin::DROLSKY::Contributors::VERSION = '0.27';
+
 use v5.10;
 
 use strict;
 use warnings;
 use autodie;
+use namespace::autoclean;
 
-use Dist::Zilla::File::InMemory;
+our $VERSION = '0.28';
 
 use Moose;
 
@@ -56,7 +57,8 @@ sub before_build {
         next if -f $file;
 
         open my $fh, '>:encoding(UTF-8)', $file;
-        print {$fh} $files{$file};
+        print {$fh} $files{$file}
+            or die "Cannot write to $files{$file}: $!";
         close $fh;
 
         push @{ $self->_files_written() }, $file;
@@ -89,7 +91,7 @@ Dist::Zilla::Plugin::DROLSKY::Contributors - Creates a weaver.ini and .mailmap t
 
 =head1 VERSION
 
-version 0.27
+version 0.28
 
 =for Pod::Coverage .*
 
@@ -99,7 +101,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Dave Rolsky.
+This software is Copyright (c) 2015 by Dave Rolsky.
 
 This is free software, licensed under:
 
