@@ -1,10 +1,13 @@
 package Dist::Zilla::Plugin::DROLSKY::License;
-$Dist::Zilla::Plugin::DROLSKY::License::VERSION = '0.27';
+
 use v5.10;
 
 use strict;
 use warnings;
 use autodie;
+use namespace::autoclean;
+
+our $VERSION = '0.28';
 
 use Module::Runtime qw( use_module );
 use String::RewritePrefix;
@@ -23,8 +26,8 @@ sub provide_license {
 
     my $license_class = String::RewritePrefix->rewrite(
         {
-            '=' => '',
-            ''  => 'Software::License::'
+            '=' => q{},
+            q{} => 'Software::License::'
         },
         $self->zilla()->_license_class() // 'Artistic_2_0',
     );
@@ -34,7 +37,7 @@ sub provide_license {
     return $license_class->new(
         {
             holder => $args->{copyright_holder} || 'David Rolsky',
-            year   => $years,
+            year => $years,
         },
     );
 }
@@ -55,7 +58,7 @@ Dist::Zilla::Plugin::DROLSKY::License - Sets up default license and copyright ho
 
 =head1 VERSION
 
-version 0.27
+version 0.28
 
 =for Pod::Coverage .*
 
@@ -65,7 +68,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Dave Rolsky.
+This software is Copyright (c) 2015 by Dave Rolsky.
 
 This is free software, licensed under:
 
