@@ -1,12 +1,13 @@
 package Dist::Zilla::PluginBundle::DROLSKY;
-# git description: v0.26-3-g93f2a34
 
-$Dist::Zilla::PluginBundle::DROLSKY::VERSION = '0.27';
 use v5.10;
 
 use strict;
 use warnings;
 use autodie;
+use namespace::autoclean;
+
+our $VERSION = '0.28';
 
 use Dist::Zilla;
 
@@ -16,16 +17,18 @@ use Pod::Weaver::Section::Contributors;
 # For the benefit of AutoPrereqs
 use Dist::Zilla::Plugin::Authority;
 use Dist::Zilla::Plugin::AutoPrereqs;
+use Dist::Zilla::Plugin::BumpVersionAfterRelease;
 use Dist::Zilla::Plugin::CheckPrereqsIndexed;
+use Dist::Zilla::Plugin::CheckVersionIncrement;
 use Dist::Zilla::Plugin::CopyFilesFromBuild;
 use Dist::Zilla::Plugin::CPANFile;
 use Dist::Zilla::Plugin::DROLSKY::Contributors;
 use Dist::Zilla::Plugin::DROLSKY::License;
+use Dist::Zilla::Plugin::DROLSKY::TidyAll;
 use Dist::Zilla::Plugin::Git::Check;
 use Dist::Zilla::Plugin::Git::CheckFor::MergeConflicts;
 use Dist::Zilla::Plugin::Git::Commit;
 use Dist::Zilla::Plugin::Git::Contributors;
-use Dist::Zilla::Plugin::Git::Describe;
 use Dist::Zilla::Plugin::Git::GatherDir;
 use Dist::Zilla::Plugin::Git::Push;
 use Dist::Zilla::Plugin::Git::Tag;
@@ -39,12 +42,10 @@ use Dist::Zilla::Plugin::MetaProvides::Package;
 use Dist::Zilla::Plugin::MetaResources;
 use Dist::Zilla::Plugin::MojibakeTests;
 use Dist::Zilla::Plugin::NextRelease;
-use Dist::Zilla::Plugin::PkgVersion;
 use Dist::Zilla::Plugin::PodSyntaxTests;
-# SurgicalPodWeaver doesn't list its deps properly
-use Dist::Zilla::Plugin::PodWeaver;
 use Dist::Zilla::Plugin::PromptIfStale;
 use Dist::Zilla::Plugin::ReadmeAnyFromPod;
+use Dist::Zilla::Plugin::RewriteVersion;
 use Dist::Zilla::Plugin::SurgicalPodWeaver;
 use Dist::Zilla::Plugin::Test::CPAN::Changes;
 use Dist::Zilla::Plugin::Test::Compile;
@@ -57,6 +58,8 @@ use Dist::Zilla::Plugin::Test::PodSpelling;
 use Dist::Zilla::Plugin::Test::Portability;
 use Dist::Zilla::Plugin::Test::ReportPrereqs;
 use Dist::Zilla::Plugin::Test::Synopsis;
+use Dist::Zilla::Plugin::Test::TidyAll;
+use Dist::Zilla::Plugin::Test::Version;
 
 use Moose;
 
@@ -232,12 +235,6 @@ sub _build_plugins {
                     . 'v %{yyyy-MM-dd}d%{ (TRIAL RELEASE)}T'
             },
         ],
-        [
-            PkgVersion => {
-                die_on_existing_version => 1,
-                die_on_line_insertion   => 1,
-            },
-        ],
         [
             'Prereqs' => 'TestMoreDoneTesting' => {
                 -phase       => 'test',
@@ -253,6 +250,7 @@ sub _build_plugins {
                 skip              => [
                     'Dist::Zilla::Plugin::DROLSKY::Contributors',
                     'Dist::Zilla::Plugin::DROLSKY::License',
+                    'Dist::Zilla::Plugin::DROLSKY::TidyAll',
                 ],
             }
         ],
@@ -289,6 +287,7 @@ sub _build_plugins {
             'Test::PodSpelling' => { stopwords => $self->_all_stopwords() },
         ],
         [ 'Test::ReportPrereqs' => { verify_prereqs => 1 }, ],
+        [ 'Test::Version'       => { is_strict      => 1 }, ],
 
         # from @Basic
         qw(
@@ -308,10 +307,10 @@ sub _build_plugins {
             CPANFile
             DROLSKY::Contributors
             DROLSKY::License
+            DROLSKY::TidyAll
             Git::CheckFor::CorrectBranch
             Git::CheckFor::MergeConflicts
             Git::Contributors
-            Git::Describe
             InstallGuide
             Meta::Contributors
             MetaConfig
@@ -328,6 +327,12 @@ sub _build_plugins {
             Test::Pod::No404s
             Test::Portability
             Test::Synopsis
+            Test::TidyAll
+            ),
+        qw(
+            RewriteVersion
+            BumpVersionAfterRelease
+            CheckVersionIncrement
             ),
 
         # from @Git - note that the order here is important!
@@ -371,7 +376,10 @@ sub _all_stopwords {
 
     if ( $self->_has_stopwords_file() ) {
         open my $fh, '<:encoding(UTF-8)', $self->stopwords_file();
-        push @stopwords, map { chomp; $_ } <$fh>;
+        while (<$fh>) {
+            chomp;
+            push @stopwords, $_;
+        }
         close $fh;
     }
 
@@ -379,7 +387,7 @@ sub _all_stopwords {
 }
 
 sub _default_stopwords {
-    qw(
+    return qw(
         DROLSKY
         DROLSKY's
         Rolsky
@@ -410,6 +418,8 @@ sub _meta_resources {
     };
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 # ABSTRACT: DROLSKY's plugin bundle
@@ -424,7 +434,7 @@ Dist::Zilla::PluginBundle::DROLSKY - DROLSKY's plugin bundle
 
 =head1 VERSION
 
-version 0.27
+version 0.28
 
 =for Pod::Coverage .*
 
@@ -434,7 +444,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Dave Rolsky.
+This software is Copyright (c) 2015 by Dave Rolsky.
 
 This is free software, licensed under:
 
